package com.brilliance.pack;

import java.util.LinkedList;
import java.util.List;

import org.junit.Before;
import org.junit.Test;

import com.brilliance.dzxt.framework.Result;
import com.brilliance.dzxt.packet.model.ActiveCurrencyAndAmount;
import com.brilliance.dzxt.packet.model.com.BrnchId;
import com.brilliance.dzxt.packet.model.com.GrpHdr;
import com.brilliance.dzxt.packet.model.com.InstdAgt;
import com.brilliance.dzxt.packet.model.com.InstgAgt;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.AdvsBkInfo;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.ApplBkInfo;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.ApplInfo;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.BfcyInfo;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.ConfBkInfo;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.ContInfo;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.Elcs_101_001_01;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.Hon;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.Instal;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.IssBkInfo;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.LCInfo;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.NegoBkInfo;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.TraNm;
import com.brilliance.dzxt.packet.model.elcs_101_001_01.TrsfBkInfo;
import com.brilliance.dzxt.utils.FastJsonUtil;
import com.brilliance.dzxt.utils.MsgUtil;

public class PackTest {
	Elcs_101_001_01 elcs_101_001_01;
	LCInfo LCInfo;
	IssBkInfo IssBkInfo;
	ApplBkInfo ApplBkInfo;
	AdvsBkInfo AdvsBkInfo;
	ApplInfo ApplInfo;
	BfcyInfo BfcyInfo;
	TraNm TraNm;
	Instal Instal;
	Hon Hon;
	ContInfo ContInfo;
	NegoBkInfo NegoBkInfo;
	TrsfBkInfo TrsfBkInfo;
	ConfBkInfo ConfBkInfo;
	GrpHdr GrpHdr;

	/**
	 * 模拟5.1	信用证开证申请报文<elcs.101.001.01>
	 */
	@Before
	public void setUp() {
		BrnchId brnchId = new BrnchId("brnchId0001");
		InstgAgt instgAgt = new InstgAgt("MmbId0001", brnchId);
		brnchId = new BrnchId("brnchId0002");
		InstdAgt instdAgt = new InstdAgt("MmbId0002", brnchId);
		GrpHdr = new GrpHdr("201908211112000001", "2010-09-01 10:09:05",
				instgAgt, instdAgt, "ELCS", "elcs_101_001_01 test");
		
		IssBkInfo = new IssBkInfo("111122333", "开证行行名", "开证行地址", "430010",
				"02782856356");
		ApplBkInfo = new ApplBkInfo("12342111", "申请人银行行名", "申请人银行地址", "430012",
				"02782856446");
		AdvsBkInfo = new AdvsBkInfo("12321212", "通知行行名", "通知行地址", "430000",
				"0278666666");
		ApplInfo = new ApplInfo("申请人名称", "7777777", "申请人地址", "430010",
				"13437568965", "62355311455", "申请人开户行行名", "66666");
		BfcyInfo = new BfcyInfo("受益人名称", "受益人地址", "430000", "1562356356",
				"752233222", "受益人开户行行名", "受益人账号");
		Instal = new Instal("ALWD", "InstallmentShipmenttAndService");
		TraNm = new TraNm("TDSV", "船运", "A码头", "B码头", "武汉船运", "运输单据签发日起10天",
				"2019-08-29", "2019-08-28", "武汉", "ALWD", Instal, "ALWD",
				"货物/服务描述", "单据要求", "附加条款", "NULL");

		Hon = new Hon("SIGT", "90", "远期付款指示",null);
		ContInfo = new ContInfo("HT00001", new ActiveCurrencyAndAmount("6.6"),
				"NULL");
		NegoBkInfo = new NegoBkInfo("DSIG", "YXHBANK", "议付行行名", "议付行地址");
		List<TrsfBkInfo> TrsfBkInfoLST = new LinkedList<TrsfBkInfo>();
		TrsfBkInfo = new TrsfBkInfo("ZLHBANK1", "转让行行名1", "转让行地址1");
		TrsfBkInfoLST.add(TrsfBkInfo);
		TrsfBkInfo = new TrsfBkInfo("ZLHBANK2", "转让行行名2", "转让行地址2");
		TrsfBkInfoLST.add(TrsfBkInfo);
		ConfBkInfo = new ConfBkInfo("BSHBANK", "保兑行行名", "保兑行地址");
		LCInfo = new LCInfo("000001", "2019-08-26",
				new ActiveCurrencyAndAmount("10"), "2.5", "3.01", "OWIS",
				IssBkInfo, ApplBkInfo, AdvsBkInfo, ApplInfo, BfcyInfo, TraNm,
				Hon, ContInfo, NegoBkInfo, TrsfBkInfoLST, ConfBkInfo);
		elcs_101_001_01 = new Elcs_101_001_01("102100099998", "103100022226",
				"20190301", "094508", "elcs.101.001.01",
				"A1234B1234C1234D1234", "00000000000000000000", "U", GrpHdr,
				LCInfo, "2019-08-26");
	}

	/**
	 * 测试利用符合电证报文结构的json字符串打包和解包
	 */
	@Test
	public void testPackAndUnpack() {
		try {
			String rawReqMessage = FastJsonUtil.toJSONString(elcs_101_001_01);
			Result reqResult = MsgUtil.packMessage(rawReqMessage);
			System.out.println("报文头==" + reqResult.getHead());
			System.out.println("签名部分==" + reqResult.getSignature());
			System.out.println("报文体部分==" + reqResult.getBody());
			System.out.println("完整报文==" + reqResult.getMessage());
			Result resResult = MsgUtil.unPackMessage(reqResult.getMessage());
			System.out.println("响应结果==" + FastJsonUtil.toJSONString(resResult));
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * 测试利用dzxt-bean提供的报文模型对象打包和解包
	 */
	@Test
	public void testPackAndUnpackBybean() {
		try {
			Result reqResult = MsgUtil.packMessage(elcs_101_001_01);
			System.out.println("报文头==" + reqResult.getHead());
			System.out.println("签名部分==" + reqResult.getSignature());
			System.out.println("报文体部分==" + reqResult.getBody());
			System.out.println("完整报文==" + reqResult.getMessage());
			Result resResult = MsgUtil.unPackMessage(reqResult.getMessage());
			System.out.println("响应结果==" + FastJsonUtil.toJSONString(resResult));
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * 测试读取
	 */
	@Test
	public void testUnpackByFile() {
	}
}
